@@ -323,7 +323,11 @@ BOOL Notepad_plus::notify(SCNotification *notification)
 				activateBuffer(bufferToClose, iView);
 			}
 
-			if (fileClose(bufferToClose, iView))
+			BufferID bufferToClose2ndCheck = notifyDocTab->getBufferByIndex(index);
+
+			if ((bufferToClose == bufferToClose2ndCheck) // Here we make sure the buffer is the same to prevent from the situation that the buffer to be close was already closed,
+			                                             // because the precedent call "activateBuffer(bufferToClose, iView)" could finally lead "doClose" call as well (in case of file non-existent).
+				&& fileClose(bufferToClose, iView))
 				checkDocState();
 
 			break;
@@ -985,38 +989,45 @@ BOOL Notepad_plus::notify(SCNotification *notification)
 					wcscpy_s(lpttt->szText, tipTmp.c_str());
 					return TRUE;
 				}
-				else if (hWin == _mainDocTab.getHSelf())
+				else 
 				{
-					BufferID idd = _mainDocTab.getBufferByIndex(id);
-					Buffer * buf = MainFileManager.getBufferByID(idd);
+					BufferID idd = BUFFER_INVALID;
+					if (hWin == _mainDocTab.getHSelf())
+						idd = _mainDocTab.getBufferByIndex(id);
+					else if (hWin == _subDocTab.getHSelf())
+						idd = _subDocTab.getBufferByIndex(id);
+					else
+						return FALSE;
+
+					Buffer* buf = MainFileManager.getBufferByID(idd);
 					if (buf == nullptr)
 						return FALSE;
 
 					tipTmp = buf->getFullPathName();
 
+					
+					if (buf->isUntitled())
+					{
+						wstring tabCreatedTime = buf->tabCreatedTimeString();
+						if (!tabCreatedTime.empty())
+						{
+							tipTmp += L"\r";
+							tipTmp += tabCreatedTime;
+							SendMessage(lpttt->hdr.hwndFrom, TTM_SETMAXTIPWIDTH, 0, 200);
+						}
+					}
+					else
+					{
+						SendMessage(lpttt->hdr.hwndFrom, TTM_SETMAXTIPWIDTH, 0, -1);
+					}
+
 					if (tipTmp.length() >= tipMaxLen)
 						return FALSE;
+
 					wcscpy_s(docTip, tipTmp.c_str());
 					lpttt->lpszText = docTip;
 					return TRUE;
 				}
-				else if (hWin == _subDocTab.getHSelf())
-				{
-					BufferID idd = _subDocTab.getBufferByIndex(id);
-					Buffer * buf = MainFileManager.getBufferByID(idd);
-					if (buf == nullptr)
-						return FALSE;
-
-					tipTmp = buf->getFullPathName();
-
-					if (tipTmp.length() >= tipMaxLen)
-						return FALSE;
-					wcscpy_s(docTip, tipTmp.c_str());
-					lpttt->lpszText = docTip;
-					return TRUE;
-				}
-				else
-					return FALSE;
 			}
 			catch (...)
 			{
