@@ -121,6 +121,7 @@ enum urlMode {urlDisable = 0, urlNoUnderLineFg, urlUnderLineFg, urlNoUnderLineBg
               urlMax = urlUnderLineBg};
 
 enum AutoIndentMode { autoIndent_none = 0, autoIndent_advanced = 1, autoIndent_basic = 2 };
+enum SysTrayAction { sta_none = 0, sta_minimize = 1, sta_close = 2 };
 
 const int LANG_INDEX_INSTR = 0;
 const int LANG_INDEX_INSTR2 = 1;
@@ -821,7 +822,7 @@ struct NppGUI final
 	bool _findWindowLessMode = false;
 
 	bool _isMaximized = false;
-	bool _isMinimizedToTray = false;
+	int _isMinimizedToTray = sta_none;
 	bool _rememberLastSession = true; // remember next session boolean will be written in the settings
 	bool _keepSessionAbsentFileEntries = false;
 	bool _isCmdlineNosessionActivated = false; // used for if -nosession is indicated on the launch time
@@ -1759,7 +1760,9 @@ public:
 	std::wstring getWinVerBitStr() const;
 	FindHistory & getFindHistory() {return _findHistory;};
 	bool _isFindReplacing = false; // an on the fly variable for find/replace functions
+#ifndef	_WIN64
 	void safeWow64EnableWow64FsRedirection(BOOL Wow64FsEnableRedirection);
+#endif
 
 	LocalizationSwitcher & getLocalizationSwitcher() {
 		return _localizationSwitcher;
