@@ -186,6 +186,8 @@ public:
 
 	bool isUntitled() const { return ((_currentStatus & DOC_UNNAMED) == DOC_UNNAMED); }
 
+	bool isFromNetwork() const { return _isFromNetwork; }
+
 	bool isInaccessible() const { return _isInaccessible; }
 	void setInaccessibility(bool val) { _isInaccessible = val; }
 
@@ -277,6 +279,20 @@ public:
 	bool getNeedReload() const { return _needReloading; }
 	void setNeedReload(bool reload) { _needReloading = reload; }
 
+	std::wstring tabCreatedTimeString() const { return _tabCreatedTimeString; }
+	void setTabCreatedTimeStringFromBakFile() {
+		if (!_isFromNetwork && _currentStatus == DOC_UNNAMED)
+			_tabCreatedTimeString = getFileTime(Buffer::ft_created); // while DOC_UNNAMED, getFileTime will retrieve time from backup file
+	}
+	void setTabCreatedTimeStringWithCurrentTime() {
+		if (_currentStatus == DOC_UNNAMED)
+		{
+			FILETIME now{};
+			GetSystemTimeAsFileTime(&now);
+			_tabCreatedTimeString = getTimeString(now);
+		}
+	}
+
 	size_t docLength() const {
 		assert(_pManager != nullptr);
 		return _pManager->docLength(_id);
@@ -286,6 +302,7 @@ public:
 
 	enum fileTimeType { ft_created, ft_modified, ft_accessed };
 	std::wstring getFileTime(fileTimeType ftt) const;
+	std::wstring getTimeString(FILETIME rawtime) const;
 
 	Lang * getCurrentLang() const;
 
@@ -374,6 +391,7 @@ private:
 	UniMode _unicodeMode = uniUTF8;
 	int _encoding = -1;
 	bool _isUserReadOnly = false;
+	bool _isFromNetwork = false;
 	bool _needLexer = false; // new buffers do not need lexing, Scintilla takes care of that
 	//these properties have to be duplicated because of multiple references
 
@@ -391,6 +409,8 @@ private:
 	wchar_t * _fileName = nullptr; // points to filename part in _fullPathName
 	bool _needReloading = false; // True if Buffer needs to be reloaded on activation
 
+	std::wstring _tabCreatedTimeString;
+
 	long _recentTag = -1;
 	static long _recentTagCtr;
 
