@@ -215,7 +215,8 @@
 	#define	IDC_HISTORY_GB_STATIC (IDD_PREFERENCE_SUB_MISC + 4)
 	#define	IDC_CHECK_DONTCHECKHISTORY (IDD_PREFERENCE_SUB_MISC + 5)
 	#define	IDC_MAXNBFILE_STATIC (IDD_PREFERENCE_SUB_MISC + 6)
-	#define	IDC_CHECK_MIN2SYSTRAY (IDD_PREFERENCE_SUB_MISC + 8)
+	#define	IDC_COMBO_SYSTRAY_ACTION_HOICE (IDD_PREFERENCE_SUB_MISC + 7)
+	#define	IDC_SYSTRAY_STATIC (IDD_PREFERENCE_SUB_MISC + 8)
 	#define	IDC_CHECK_REMEMBERSESSION (IDD_PREFERENCE_SUB_MISC + 9)
 	#define	IDC_INDENTUSING_STATIC (IDD_PREFERENCE_SUB_MISC + 10)
 	#define	IDC_RADIO_USINGTAB (IDD_PREFERENCE_SUB_MISC + 11)
